@@ -43,7 +43,7 @@ def DumpsTorch(obj, pickle_protocol:Optional[int]=None, _use_new_zipfile_seriali
         pickle_protocol (int/None): The `pickle_protocol` argument for `torch.save`.
         _use_new_zipfile_serialization (int/None): The `_use_new_zipfile_serialization` argument for `torch.save`.
     Returns:
-        None
+        bytearray: The torch bytearray.
     """
     buff = io.BytesIO()
     if pickle_protocol is not None:
@@ -154,6 +154,7 @@ class FC(nn.Module):
         activation=nn.Identity(),
         dropout:Optional[int]=None,
         dropout_inplace:bool=True,
+        flatten=True,
     ):
         super(FC, self).__init__()
         self.input_dim = input_dim; self.output_dim = output_dim
@@ -163,9 +164,10 @@ class FC(nn.Module):
         +   ([norm_layer] if norm_layer is not None else [])
         +   ([activation] if activation is not None else [])
         ))
+        self.flatten = flatten
     
     def forward(self, data):
-        return self.layers(torch.flatten(data,start_dim=1))
+        return self.layers(torch.flatten(data,start_dim=1)) if self.flatten else self.layers(data)
 
 class CONV(nn.Module):
     def __init__(
